==> open-xchange-core_7.4.0.orig.tar.bz2: open-xchange-core-7.4.0/com.openexchange.server/src/com/openexchange/server/impl/DBPool.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.server.impl;

import java.sql.Connection;
import com.openexchange.databaseold.Database;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.contexts.Context;

/**
 * DBPool
 * @author <a href="mailto:martin.kauss@open-xchange.org">Martin Kauss</a>
 */
public class DBPool  {

    public static final Connection pickup() throws OXException {
        return Database.get(false);
    }

    public static final Connection pickup(final Context context) throws OXException {
        return Database.get(context, false);
    }

    public static final Connection pickupWriteable() throws OXException {
        return Database.get(true);
    }

    public static final Connection pickupWriteable(final Context context) throws OXException {
        return Database.get(context, true);
    }

    public static final boolean push(final Connection con) {
        if (null != con) {
            Database.back(false, con);
        }
        return true;
    }

    public static final boolean push(final Context context, final Connection con) {
        if (null != con) {
            Database.back(context, false, con);
        }
        return true;
    }

    public static final boolean pushWrite(final Connection con) {
        if (null != con) {
            Database.back(true, con);
        }
        return true;
    }

    public static final boolean pushWrite(final Context context, final Connection con) {
        if (null != con) {
            Database.back(context, true, con);
        }
        return true;
    }

    public static final void closeReaderSilent(final Connection con) {
        if (null != con) {
            Database.back(false, con);
        }
    }

    public static final void closeReaderSilent(final Context context, final Connection con) {
        if (null != con) {
            Database.back(context, false, con);
        }
    }

    public static final void closeWriterSilent(final Connection con) {
        if (null != con) {
            Database.back(true, con);
        }
    }

    public static final void closeWriterSilent(final Context context, final Connection con) {
        if (null != con) {
            Database.back(context, true, con);
        }
    }

    public static final void closeWriterAfterReading(final Context context, final Connection con) {
        if (null != con) {
            Database.backAfterReading(context, con);
        }
    }
}

==> open-xchange-core_7.4.1.orig.tar.bz2: open-xchange-core-7.4.1/com.openexchange.server/src/com/openexchange/server/impl/DBPool.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.server.impl;

import java.sql.Connection;
import com.openexchange.databaseold.Database;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.contexts.Context;

/**
 * DBPool
 * @author <a href="mailto:martin.kauss@open-xchange.org">Martin Kauss</a>
 */
public class DBPool  {

    public static final Connection pickup() throws OXException {
        return Database.get(false);
    }

    public static final Connection pickup(final Context context) throws OXException {
        return Database.get(context, false);
    }

    public static final Connection pickupWriteable() throws OXException {
        return Database.get(true);
    }

    public static final Connection pickupWriteable(final Context context) throws OXException {
        return Database.get(context, true);
    }

    public static final boolean push(final Connection con) {
        if (null != con) {
            Database.back(false, con);
        }
        return true;
    }

    public static final boolean push(final Context context, final Connection con) {
        if (null != con) {
            Database.back(context, false, con);
        }
        return true;
    }

    public static final boolean pushWrite(final Connection con) {
        if (null != con) {
            Database.back(true, con);
        }
        return true;
    }

    public static final boolean pushWrite(final Context context, final Connection con) {
        if (null != con) {
            Database.back(context, true, con);
        }
        return true;
    }

    public static final void pushWriteAfterReading(Context ctx, Connection con) {
        if (null != con) {
            Database.backAfterReading(ctx, con);
        }
    }

    public static final void closeReaderSilent(final Connection con) {
        if (null != con) {
            Database.back(false, con);
        }
    }

    public static final void closeReaderSilent(final Context context, final Connection con) {
        if (null != con) {
            Database.back(context, false, con);
        }
    }

    public static final void closeWriterSilent(final Connection con) {
        if (null != con) {
            Database.back(true, con);
        }
    }

    public static final void closeWriterSilent(final Context context, final Connection con) {
        if (null != con) {
            Database.back(context, true, con);
        }
    }

    public static final void closeWriterAfterReading(final Context context, final Connection con) {
        if (null != con) {
            Database.backAfterReading(context, con);
        }
    }
}
